@@ -77,9 +77,6 @@ extern int do_eeprom_programming(UPSINFO *ups);
 extern int parse_options(int argc, char *argv[]);
 
 /* In apcupsd.c */
-extern void powerfail(int ok);
-extern void logonfail(int ok);
-
 extern void apc_thread_terminate(int sig);
 extern void clean_threads(void);
 extern void apcupsd_terminate(int sig);
@@ -127,9 +124,7 @@ extern int make_file(UPSINFO *ups, const char *path);
 extern void make_pid_file(void);
 
 /* In apcconfig.c */
-extern int slave_count;
-extern SLAVEINFO slaves[MAXSLAVES];
-
+extern char APCCONF[APC_FILENAME_MAX];
 extern void init_ups_struct(UPSINFO *ups);
 extern void check_for_config(UPSINFO *ups, char *cfgfile);
 
@@ -237,12 +232,11 @@ extern void generic_error_out(const char *file, int line, const char *fmt, ...);
 extern void generic_error_exit(const char *fmt, ...);
 
 /* In asys.c */
-int amicrosleep(time_t sec, long usec);
 int avsnprintf(char *str, size_t size, const char *format, va_list ap);
 int asnprintf(char *str, size_t size, const char *fmt, ...);
 char *astrncpy(char *dest, const char *src, int maxlen);
 char *astrncat(char *dest, const char *src, int maxlen);
-struct tm *localtime_r(const time_t *timep, struct tm *tm);
+//struct tm *localtime_r(const time_t *timep, struct tm *tm);
 char *afgets(char *s, int size, FILE *fd);
 void *amalloc(size_t size);
 void *arealloc(void *buf, size_t size);
@@ -251,4 +245,9 @@ void *acalloc(size_t size1, size_t size2);
 /* In apcwinipc.c */
 int winioctl(int fd, int func, int *addr);
 
+/* In sleep.c */
+#ifndef HAVE_NANOSLEEP
+  int nanosleep(const struct timespec *req, struct timespec *rem);
+#endif
+
 #endif   /* _EXTERN_H */
