@@ -55,36 +55,31 @@ typedef enum {
    DUMB_UPS,            /* Dumb UPS driver      */
    BK,                  /* Simple Signal        */
    SHAREBASIC,          /* Simple Signal, Share */
-   NETUPS,              /*                      */
    BKPRO,               /* SubSet Smart Signal  */
    VS,                  /* SubSet Smart Signal  */
    NBKPRO,              /* Smarter BKPRO Signal */
    SMART,               /* Smart Signal         */
    MATRIX,              /* Smart Signal         */
    SHARESMART,          /* Smart Signal, Share  */
-   APCSMART_UPS,        /* APC Smart UPS (any) */
+   APCSMART_UPS,        /* APC Smart UPS (any)  */
    USB_UPS,             /* USB UPS driver       */
    SNMP_UPS,            /* SNMP UPS driver      */
    NETWORK_UPS,         /* NETWORK UPS driver   */
-   TEST_UPS             /* TEST UPS Driver      */
+   TEST_UPS,            /* TEST UPS Driver      */
+   PCNET_UPS,           /* PCNET UPS Driver     */
 } UpsMode;
 
 typedef enum {
    NO_CLASS = 0,
    STANDALONE,
    SHARESLAVE,
-   NETSLAVE,
    SHAREMASTER,
-   NETMASTER,
-   SHARENETMASTER
 } ClassMode;
 
 typedef enum {
    NO_SHARE_NET = 0,
    DISABLE,             /* Disable Share or Net UPS  */
    SHARE,               /* ShareUPS Internal         */
-   NET,                 /* NetUPS                    */
-   SHARENET             /* Share and Net, Master     */
 } ShareNetMode;
 
 typedef enum {
@@ -133,28 +128,6 @@ typedef enum {
    TEST_UNKNOWN
 } SelfTestResult;
 
-/*
- * Internal selftest structure.
- * This structure is made by two variables, one for client side
- * and one for server side.
- * "activate" is the client side flag to activate a particular self
- * test. The client switch this flag to TRUE and then starts monitoring
- * the value of "status". The server (apcupsd) monitors the value of
- * "activate" and when it's true, enters the selftest state machine,
- * updating the value of "status" as the selftest proceed.
- * At the end of the selftest, apcupsd resets the value of "activate" to false
- * and leave the value of "status" to one of the possible selftest final
- * status.
- * It is important to say that the state machine rely in an array internal to
- * the UPSINFO structure so that every capable UPS can do asyncronously a
- * selftest.
- */
-typedef struct SELFTEST {
-   int activate;
-   int status;
-} SELFTEST;
-
-
 typedef struct geninfo {
    const char *name;               /* JHNC: name mustn't contain whitespace */
    const char *long_name;
@@ -167,68 +140,11 @@ typedef struct internalgeninfo {
    int type;
 } INTERNALGENINFO;                 /* for assigning into upsinfo */
 
-/* Structure that contains information on each of our slaves.
- * Also, for a slave, the first slave packet is info on the
- * master.
- */
-typedef struct slaveinfo {
-   int remote_state;               /* state of master */
-   int disconnecting_slave;        /* set if old style slave */
-   int ms_errno;                   /* errno last error */
-   int socket;                     /* current open socket this slave */
-   int port;                       /* port */
-   int error;                      /* set when error message printed */
-   int errorcnt;                   /* count of errors */
-   time_t down_time;               /* time slave was set RMT_DOWN */
-   struct sockaddr_in addr;
-   char usermagic[APC_MAGIC_SIZE]; /* Old style password */
-   char name[MAXTOKENLEN];         /* master/slave domain name (or IP) */
-   char password[MAXTOKENLEN];     /* for CRAM-MD5 authentication */
-} SLAVEINFO;
-
-/* 
- * This structure is sent over the network between the    
- * master and the slaves, so we make the
- * length of character arrays a multiple of four and
- * keep the chars at the end to minimize memory alignment
- * problems. 
- */
-typedef struct netdata {
-   int32_t OnBatt;
-   int32_t BattLow;
-   int32_t BatteryUp;
-   int32_t BattChg;
-   int32_t ShutDown;
-   int32_t nettime;
-   int32_t TimeLeft;
-   int32_t ChangeBatt;
-   int32_t load;
-   int32_t timedout;
-   int32_t timelout;
-   int32_t emergencydown;
-   int32_t remote_state;
-   int32_t cap_battlev;
-   int32_t cap_runtim;
-   char apcmagic[APC_MAGIC_SIZE];
-   char usermagic[APC_MAGIC_SIZE];
-} NETDATA;
-
-
-/* No longer really needed since we do not use shared memory */
-#define UPSINFO_VERSION 12
-
-/*
- * There is no need to change the following, but you can if
- * you want, but it must be at least 4 characters to match
- * the length of id[4] (not counting the EOS).
- */
-#define UPSINFO_ID "UPS!"
 
 class UPSINFO {
  public:
    /* Methods */
    void clear_battlow() { Status &= ~UPS_battlow; };
-   void clear_belowcaplimit() { Status &= ~UPS_belowcaplimit; };
    void clear_boost() { Status &= ~UPS_boost; };
    void clear_calibration() { Status &= ~UPS_calibration; };
    void clear_commlost() { Status &= ~UPS_commlost; };
@@ -239,10 +155,8 @@ class UPSINFO {
    void clear_online() { Status |= UPS_onbatt; Status &= ~UPS_online; };
    void clear_overload() { Status &= ~UPS_overload; };
    void clear_plugged() { Status &= ~UPS_plugged; };
-   void clear_remtimelimit() { Status &= ~UPS_remtimelimit; };
    void clear_replacebatt() { Status &= ~UPS_replacebatt; };
    void clear_shut_btime() { Status &= ~UPS_shut_btime; };
-   void clear_shutdownimm() { Status &= ~UPS_shutdownimm; };
    void clear_shutdown() { Status &= ~UPS_shutdown; };
    void clear_shut_emerg() { Status &= ~UPS_shut_emerg; };
    void clear_shut_load() { Status &= ~UPS_shut_load; };
@@ -255,7 +169,6 @@ class UPSINFO {
 
    void set_battlow() { Status |= UPS_battlow; };
    void set_battlow(int val) { if (val) set_battlow(); else clear_battlow(); };
-   void set_belowcaplimit() { Status |= UPS_belowcaplimit; };
    void set_boost() { Status |= UPS_boost; };
    void set_boost(int val) { if (val) set_boost(); else clear_boost(); };
    void set_calibration() { Status |= UPS_calibration; };
@@ -269,13 +182,10 @@ class UPSINFO {
    void set_overload() { Status |= UPS_overload; };
    void set_overload(int val) { if (val) set_overload(); else clear_overload(); };
    void set_plugged() { Status |= UPS_plugged; };
-   void set_remtimelimit() { Status |= UPS_remtimelimit; };
    void set_replacebatt() { Status |= UPS_replacebatt; };
    void set_replacebatt(int val) { if (val) set_replacebatt(); else clear_replacebatt(); };
    void set_shut_btime() { Status |= UPS_shut_btime; };
    void set_shut_btime(int val) { if (val) set_shut_btime(); else clear_shut_btime(); };
-   void set_shutdownimm() { Status |= UPS_shutdownimm; };
-   void set_shutdownimm(int val) { if (val) set_shutdownimm(); else clear_shutdownimm(); };
    void set_shutdown() { Status |= UPS_shutdown; };
    void set_shut_emerg() { Status |= UPS_shut_emerg; };
    void set_shut_emerg(int val) { if (val) set_shut_emerg(); else clear_shut_emerg(); };
@@ -305,7 +215,6 @@ class UPSINFO {
    bool is_plugged() const { return (Status & UPS_plugged) == UPS_plugged; };
    bool is_replacebatt() const { return (Status & UPS_replacebatt) == UPS_replacebatt; };
    bool is_shut_btime() const { return (Status & UPS_shut_btime) == UPS_shut_btime; };
-   bool is_shutdownimm() const { return (Status & UPS_shutdownimm) == UPS_shutdownimm; };
    bool is_shutdown() const { return (Status & UPS_shutdown) == UPS_shutdown; };
    bool is_shut_emerg() const { return (Status & UPS_shut_emerg) == UPS_shut_emerg; };
    bool is_shut_load() const { return (Status & UPS_shut_load) == UPS_shut_load; };
@@ -319,6 +228,7 @@ class UPSINFO {
    bool chg_battlow() const { return ((Status ^ PrevStatus) & UPS_battlow) == UPS_battlow; };
    bool chg_onbatt() const { return ((Status ^ PrevStatus) & UPS_onbatt) == UPS_onbatt; };
    bool chg_battpresent() const { return ((Status ^ PrevStatus) & UPS_battpresent) == UPS_battpresent; };
+   bool chg_shut_remote() const { return ((Status ^ PrevStatus) & UPS_shut_remote) == UPS_shut_remote; };
 
    /* DATA */
    char release[20];
@@ -329,12 +239,11 @@ class UPSINFO {
    char UPS_Cap[CI_MAXCI + 1];          /* TRUE if UPS has capability */
    unsigned int UPS_Cmd[CI_MAXCI + 1];  /* Command or function code */
 
-   INTERNALGENINFO cable;
-   INTERNALGENINFO enable_access;
-   INTERNALGENINFO nologin;
-   INTERNALGENINFO mode;
-   INTERNALGENINFO upsclass;
-   INTERNALGENINFO sharenet;
+   INTERNALGENINFO cable;          /* UPSCABLE directive */
+   INTERNALGENINFO nologin;        /* NOLOGON directive */
+   INTERNALGENINFO mode;           /* UPSTYPE directive */
+   INTERNALGENINFO upsclass;       /* UPSCLASS directive */
+   INTERNALGENINFO sharenet;       /* UPSMODE directive */
 
    int num_execed_children;        /* children created in execute_command() */
 
@@ -351,6 +260,9 @@ class UPSINFO {
    time_t last_time_nologon;
    time_t last_time_changeme;
    time_t last_master_connect_time;     /* last time master connected */
+   time_t start_shut_ltime;
+   time_t start_shut_load;
+   time_t start_shut_lbatt;
    int num_xfers;                  /* number of times on batteries */
    int cum_time_on_batt;           /* total time on batteries since startup */
    int wait_time;                  /* suggested wait time for drivers in 
@@ -388,7 +300,8 @@ class UPSINFO {
 
    /* Items reported by smart UPS */
    /* Static items that normally do not change during UPS operation */
-   int NomOutputVoltage;           /* Nominial voltage when on batteries */
+   int NomOutputVoltage;           /* Nominal voltage when on batteries */
+   int NomInputVoltage;            /* Nominal input voltage */
    double nombattv;                /* Nominal batt. voltage -- not actual */
    int extbatts;                   /* number of external batteries attached */
    int badbatts;                   /* number of bad batteries */
@@ -419,7 +332,7 @@ class UPSINFO {
    int stattime;
    int datatime;
    int sysfac;
-   int nettime;                    /* Time interval for master to send to slaves */
+   int nettime;                    /* Time interval for slaves to poll master */
    int percent;                    /* shutdown when batt % less than this */
    int runtime;                    /* shutdown when runtime less than this */
    char nisip[64];                 /* IP for NIS */
@@ -433,15 +346,15 @@ class UPSINFO {
    int eventfilemax;               /* max size of eventfile in kilobytes */
    int event_fd;                   /* fd for eventfile */
 
-   int NetUpsPort;                 /* Master/slave port */
    char master_name[APC_FILENAME_MAX];
    char lockpath[APC_FILENAME_MAX];
    int lockfile;
 
-   char usermagic[APC_MAGIC_SIZE]; /* security id string */
-   int ChangeBattCounter;          /* For UPS_REPLACEBATT, see apcaction.c */
+   char scriptdir[APC_FILENAME_MAX];    /* Path to apccontrol dir */
+   char pwrfailpath[APC_FILENAME_MAX];  /* Path to powerfail flag file dir */
+   char nologinpath[APC_FILENAME_MAX];  /* Path to nologin dir */
 
-   int remote_state;
+   int ChangeBattCounter;          /* For UPS_REPLACEBATT, see apcaction.c */
 
    pthread_mutex_t mutex;
    int refcnt;                     /* thread attach count */
@@ -450,39 +363,6 @@ class UPSINFO {
    void *driver_internal_data;     /* Driver private data */
 };
 
-/* Used only in apcaccess.c */
-typedef struct datainfo {
-   char apcmagic[APC_MAGIC_SIZE];
-   int update_master_config;
-   int get_master_status;
-   int slave_status;
-   int call_master_shutdown;
-   char accessmagic[ACCESS_MAGIC_SIZE];
-} DATAINFO;
-
-typedef int (HANDLER) (UPSINFO *, int, const GENINFO *, const char *);
-
-typedef struct {
-   const char *key;
-   HANDLER *handler;
-   size_t offset;
-   const GENINFO *values;
-   const char *help;
-} PAIRS;
-
-typedef struct configinfo {
-   int new_annoy;
-   int new_maxtime;
-   int new_delay;
-#ifdef __NOLOGIN
-   int new_nologin;
-#endif  /* __NOLOGIN */
-   int new_stattime;
-   int new_datatime;
-   int new_nettime;
-   int new_percent;
-} CONFIGINFO;
-
 
 /*These are needed for commands executed in apcaction.c */
 typedef struct {
