@@ -65,16 +65,13 @@ void setup_device(UPSINFO *ups)
    /* If create_lockfile fails there's no need to delete_lockfile. */
    if ((ups->fd != -1) && create_lockfile(ups) == LCKERROR) {
       device_close(ups);
-      Error_abort0(_("Unable to create UPS lock file.\n"));
+      Error_abort0(_("Unable to create UPS lock file.\n"
+                     "  If apcupsd or apctest is already running,\n"
+                     "  please stop it and run this program again.\n"));
    }
 
    device_setup(ups);
-
-   /* Must not be called on slaves */
-   if (!ups->is_slave())
-      device_get_capabilities(ups);
-
-   return;
+   device_get_capabilities(ups);
 }
 
 /*********************************************************************/
@@ -98,7 +95,7 @@ void kill_power(UPSINFO *ups)
     * above only tests UPS_onbatt flag for dumb UPSes.
     */
     
-   pwdf = fopen(PWRFAIL, "r");
+   pwdf = fopen(ups->pwrfailpath, "r");
    if ((pwdf == NULL && ups->mode.type != BK) ||
        (pwdf == NULL && ups->is_onbatt() && ups->mode.type == BK)) {
       
@@ -114,24 +111,19 @@ void kill_power(UPSINFO *ups)
 
       /* Now complain */
       log_event(ups, LOG_WARNING,
-         _("Cannot find " PWRFAIL " file.\n Killpower requested in "
+         _("Cannot find %s file.\n Killpower requested in "
            "non-power fail condition or bug.\n Killpower request "
-           "ignored at %s:%d\n"), __FILE__, __LINE__);
-      Error_abort2(
-         _("Cannot find " PWRFAIL " file.\n Killpower requested in "
+           "ignored at %s:%d\n"), ups->pwrfailpath, __FILE__, __LINE__);
+      Error_abort3(
+         _("Cannot find %s file.\n Killpower requested in "
            "non-power fail condition or bug.\n Killpower request "
-           "ignored at %s:%d\n"), __FILE__, __LINE__);
+           "ignored at %s:%d\n"), ups->pwrfailpath, __FILE__, __LINE__);
    } else {
       /* We are on batteries, so do the kill_power */
-      if ((ups->upsclass.type == SHAREMASTER) ||
-         (ups->upsclass.type == SHARENETMASTER)) {
+      if (ups->upsclass.type == SHAREMASTER) {
          log_event(ups, LOG_WARNING,
             _("Waiting 30 seconds for slave(s) to shutdown."));
          sleep(30);
-      } else if (ups->upsclass.type == NETMASTER) {
-         log_event(ups, LOG_WARNING,
-            _("Waiting 30 seconds for slave(s) to shutdown"));
-         sleep(30);
       }
 
       /* close the powerfail file */
