@@ -5,7 +5,7 @@
  */
 
 /*
- * Copyright (C) 2001-2004 Kern Sibbald
+ * Copyright (C) 2001-2006 Kern Sibbald
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General
@@ -224,10 +224,12 @@ static int poll_ups(UPSINFO *ups)
 
    Dmsg2(20, "Opening connection to %s:%d\n", nid->hostname, nid->port);
    if ((nid->sockfd = net_open(nid->hostname, NULL, nid->port)) < 0) {
-      log_event(ups, LOG_ERR, "fetch_data: tcp_open failed for %s port %d",
-         nid->hostname, nid->port);
       Dmsg0(90, "Exit poll_ups 0 comm lost\n");
-      ups->set_commlost();
+      if (!ups->is_commlost()) {
+         log_event(ups, LOG_ERR, "fetch_data: tcp_open failed for %s port %d",
+            nid->hostname, nid->port);
+         ups->set_commlost();
+      }
       return 0;
    }
 
@@ -381,8 +383,7 @@ static int get_ups_status_flag(UPSINFO *ups, int fill)
 
    Dmsg2(100, "Got Status = %s 0x%x\n", answer, ups->Status);
 
-   if (masterStatus & (UPS_shutdown | UPS_shutdownimm |
-                       UPS_belowcaplimit | UPS_remtimelimit)) {
+   if (masterStatus & UPS_shutdown && !ups->is_shut_remote()) {
       ups->set_shut_remote();    /* if master is shutting down so do we */
       log_event(ups, LOG_ERR, "Shutdown because NIS master is shutting down.");
       Dmsg0(100, "Set SHUT_REMOTE because of master status.\n");
@@ -395,7 +396,7 @@ static int get_ups_status_flag(UPSINFO *ups, int fill)
     * is called once per second.
     */
    if (stat == 0 && ups->is_onbatt()) {
-      if (comm_loss++ == 4) {
+      if (comm_loss++ == 4 && !ups->is_shut_remote()) {
          ups->set_shut_remote();
          log_event(ups, LOG_ERR,
             "Shutdown because loss of comm with NIS master while on batteries.");
