@@ -141,7 +141,11 @@ int powernet_snmp_ups_get_capabilities(UPSINFO *ups)
       if (i != CI_NOMBATTV &&
           i != CI_HUMID    &&
           i != CI_ATEMP    &&
-          i != CI_VBATT)
+          i != CI_VBATT    &&
+          i != CI_NOMINV   &&
+          i != CI_REG1     &&
+          i != CI_REG2     &&
+          i != CI_REG3)
          ups->UPS_Cap[i] = TRUE;
    }
 
@@ -151,22 +155,6 @@ int powernet_snmp_ups_get_capabilities(UPSINFO *ups)
    return 1;
 }
 
-#define MIN(a, b) ( ((a) < (b)) ? (a) : (b) )
-
-/*
- * Copy a string from the SNMP library structure into the UPSINFO structure.
- * Structure member names are formed by simple patterns, so allow the caller
- * to specify nice readable names and build the ugly ones ourself. Source
- * strings are NOT nul-terminated, so let astrncpy terminate them for us.
- */
-#define SNMP_STRING(oid, field, dest) \
-   do \
-   {  \
-      astrncpy(ups->dest, \
-         (const char *)data->oid->oid##field, \
-         MIN(sizeof(ups->dest), data->oid->_##oid##field##Length+1)); \
-   }  \
-   while(0)
 
 int powernet_snmp_ups_read_static_data(UPSINFO *ups)
 {
@@ -339,7 +327,6 @@ int powernet_snmp_ups_read_volatile_data(UPSINFO *ups)
    if (data->upsAdvBattery) {
       ups->BattChg = data->upsAdvBattery->__upsAdvBatteryCapacity;
       ups->UPSTemp = data->upsAdvBattery->__upsAdvBatteryTemperature;
-      ups->UPSTemp = data->upsAdvBattery->__upsAdvBatteryTemperature;
       ups->TimeLeft = data->upsAdvBattery->__upsAdvBatteryRunTimeRemaining / 6000;
 
       if (data->upsAdvBattery->__upsAdvBatteryReplaceIndicator == 2)
@@ -499,6 +486,7 @@ int powernet_snmp_ups_check_state(UPSINFO *ups)
    fd_set fds;
    int numfds, rc, block;
    struct timeval tmo, exit, now;
+   int sleep_time;
 
    /* Check for commlost under lock since UPS status might be changed */
    write_lock(ups);
@@ -507,15 +495,20 @@ int powernet_snmp_ups_check_state(UPSINFO *ups)
    if (rc == 0)
       return 0;
 
+   /* Allow user to reduce sleep_time using NETTIME config setting */
+   sleep_time = ups->wait_time;
+   if (ups->nettime && ups->nettime < ups->wait_time)
+      sleep_time = ups->nettime;
+
    /* If we're not doing SNMP traps, just sleep and exit */
    if (!Sid->trap_session) {
-      sleep(ups->wait_time);
+      sleep(sleep_time);
       return 1;
    }
 
    /* Figure out when we need to exit by */
    gettimeofday(&exit, NULL);
-   exit.tv_sec += ups->wait_time;
+   exit.tv_sec += sleep_time;
 
    while(1)
    {
@@ -578,8 +571,12 @@ int powernet_snmp_ups_open(UPSINFO *ups)
    struct snmp_session *s = &my_data->session;
    struct snmp_session tmp;
 
-   /* If we're configured to not use traps, just exit */
+   /*
+    * If we're configured to not use traps, simply rename
+    * DeviceVendor to 'APC' and exit.
+    */
    if (!strcmp(my_data->DeviceVendor, "APC_NOTRAP")) {
+      my_data->DeviceVendor[3] = '\0';
       Dmsg0(100, "User requested no traps\n");
       return 1;
    }
