@@ -39,6 +39,7 @@
 #else
 
 # ifdef HAVE_NET_SNMP
+#  include <net-snmp/net-snmp-config.h>
 #  include <net-snmp/library/asn1.h>
 #  include <net-snmp/library/snmp.h>
 #  include <net-snmp/library/snmp_api.h>
@@ -50,6 +51,23 @@
 #include "powernet-mib.h"
 #include "rfc1628-mib.h"
 
+#include <sys/param.h>   /* for MIN() */
+
+/*
+ * Copy a string from the SNMP library structure into the UPSINFO structure.
+ * Structure member names are formed by simple patterns, so allow the caller
+ * to specify nice readable names and build the ugly ones ourself. Source
+ * strings are NOT nul-terminated, so let astrncpy terminate them for us.
+ */
+#define SNMP_STRING(oid, field, dest) \
+   do \
+   {  \
+      astrncpy(ups->dest, \
+         (const char *)data->oid->oid##field, \
+         MIN(sizeof(ups->dest), data->oid->_##oid##field##Length+1)); \
+   }  \
+   while(0)
+
 /*********************************************************************/
 /* Internal structures                                               */
 /*********************************************************************/
