@@ -179,6 +179,37 @@ int parse_options(int argc, char *argv[])
       }
    }
 
+/* Win32-specific dynamic path handling... */
+#ifdef HAVE_WIN32
+   extern char sbindir[MAXSTRING];
+
+   /* Obtain full path to this executable */
+   DWORD len = GetModuleFileName(NULL, sbindir, sizeof(sbindir)-1);
+   sbindir[len] = '\0';
+   Dmsg1(200, "Exepath: %s\n", sbindir);
+   if (len == 0) {
+      /* Failed to get path, so make an assumption */
+      asnprintf(sbindir, sizeof(sbindir), "C:\\apcupsd\\bin\\apcupsd.exe");
+   }
+
+   /* Strip trailing filename component */
+   char *ptr = strrchr(sbindir, '\\');
+   if (ptr)
+      *ptr = '\0';
+   else
+      sbindir[0] = '\0';
+
+   /*
+    * If the user did not provide a -f argument to specify
+    * the location of apcupsd.conf, simulate one relative to current
+    * executable path.
+    */
+   if (cfgfile == APCCONF) {
+      asnprintf(APCCONF, sizeof(APCCONF),
+         "%s\\..\\etc\\apcupsd%s", sbindir, APCCONF_FILE);
+   }
+#endif
+
    if ((oneshot == TRUE) && options > 1) {
       fprintf(stderr, _("\nError: too many arguments.\n\n"));
       errflag++;
